xp2p_sdk library
XP2P SDK for Flutter
腾讯物联网 XP2P SDK,提供 P2P 连接功能,支持视频直播、回放、语音对讲等功能。
Classes
- AppConfig
- 应用配置 用于配置 P2P 连接的服务器和网络参数 对应 Android 的 AppConfig.java
- AtomicInt
- BoolMsg
- BoolPlayerMsg
- CachePathMsg
- Command
- CommonUtils
- Common utility class 通用工具类
- ConfigUtil
- 配置工具类
- DataReport
- 用于上报 P2P 连接的统计数据
- DoubleMsg
- DoublePlayerMsg
- DownloadQuality
- FileUtils
- FLVPacker
- FPlayerPckInfo
- FSteamInfo
- FTXLiveListener
- FTXLiveLocalRecordingParams
- FTXLivePlayConfig
- TXLivePlayer config
- FTXLivePlayConfigPlayerMsg
- FTXVodPlayConfig
- TXVodPlayer config
- FTXVodPlayConfigPlayerMsg
- IntMsg
- IntPlayerMsg
- LicenseMsg
- ListMsg
- LogConfig
- Logger
- 日志工具类
- LogUtils
- log print tools
- MapMsg
- PipParamsPlayerMsg
- PlayerMsg
-
Pigeon original component, used to generate native communication code for
messages. The generation command is as follows. When using the generation command, the two import statements above need to be implemented or commented out. - PlayerType
- Effective only on iOS platform.
- PreLoadInfoMsg
- PreLoadMsg
- SoundTouch
- SoundTouch 高级封装类
- SoundTouchSetting
- SoundTouch 设置 ID 常量
- StringListPlayerMsg
- StringMsg
- StringOptionPlayerMsg
- StringPlayerMsg
- SubTitlePlayerMsg
- SubTitleRenderModelPlayerMsg
- SuperPlayerPlugin
- TXDownloadFlutterAPI
- TXDownloadListMsg
- TXFlutterDownloadApi
- TXFlutterLivePlayerApi
- TXFlutterNativeAPI
- TXFlutterSuperPlayerPluginAPI
- TXFlutterVodPlayerApi
- TXLivePlayerController
- TXLivePlayerFlutterAPI
- TXLogLevel
- TXModel
- TXPipFlutterAPI
- TXPlayerController
- TXPlayerDrmBuilder
- DRM playback information DRM播放信息
- TXPlayerDrmMsg
- TXPlayerHolder
- TXPlayerType
- Player type.
- TXPlayerValue
- TXPlayerVideo
- TXPlayerVideoState
- TXPlayInfoParams
- TXPlayInfoParamsPlayerMsg
- TXPlayType
- Live stream type.
- TXPluginFlutterAPI
- TXSubtitleRenderModel
- TXTrackInfo
- Track details 轨道的详细信息
- TXVodDownloadController
- include features:
- TXVodDownloadDataSource
- File ID storage. fileId存储
- TXVodDownloadMediaInfo
- Video download information. 视频下载信息
- TXVodDownloadMediaMsg
- TXVodNetEvent
- TXVodPlayerController
- TXVodPlayerFlutterAPI
- TXVodPlayEvent
- TXVodSubtitleData
- UInt8ListMsg
- XP2P
- XP2P SDK 主类 提供 P2P 视频流传输的核心功能
- XP2PAppConfig
- XP2P 应用配置
- XP2PCallback
- XP2P 回调接口
Enums
- FTXAndroidRenderViewType
- render view type for android If it is DRM playback, you may need to switch to SurfaceView mode. The default mode is TextureView.
- FTXPlayerRenderMode
- 画面平铺模式
- LogLevel
- TXDrmProvisionEnv
- TXPlayerEvent
- TXPlayerLiveMode
- TXPlayerState
- XP2PCloseSubType
- XP2P 关闭子类型 用于标识服务关闭的具体类型
- XP2PErrorCode
- XP2P 错误码定义
- XP2PProtocolType
- XP2P 协议类型 用于指定 P2P 连接使用的网络协议
- XP2PType
- XP2P 事件类型 用于标识不同类型的回调事件
Functions
-
wrapResponse(
{Object? result, PlatformException? error, bool empty = false}) → List< Object?>
Typedefs
- FLVDataCallback = void Function(Uint8List flvData)
- FTXDownlodOnErrorListener = void Function(int errorCode, String errorMsg, TXVodDownloadMediaInfo info)
- FTXDownlodOnStateChangeListener = void Function(int event, TXVodDownloadMediaInfo info)
- FTXLicenceLoadedListener = void Function(int result, String reason)
- FTXLiveLocalRecordBegin = void Function(int code, String storagePath)
- FTXLiveLocalRecordComplete = void Function(int code, String storagePath)
- FTXLiveLocalRecording = void Function(int durationMs, String storagePath)
- FTXLiveSnapshotComplete = void Function(Uint8List? imageBytes)
- FTXOnRenderViewCreatedListener = void Function(int viewId)
- FTXPredownlodOnCompleteListener = void Function(int taskId, String url)
- FTXPredownlodOnErrorListener = void Function(int taskId, String url, int code, String msg)
- FTXPredownlodOnStartListener = void Function(int taskId, String fileId, String url, Map params)
-
OnResultListener<
T> = void Function(T result)